@@ -5,12 +5,12 @@ extern crate test;
 use {
     rand::{thread_rng, Rng},
     solana_runtime::{
-        accounts_db::AccountInfo,
+        account_info::AccountInfo,
         accounts_index::{
             AccountSecondaryIndexes, AccountsIndex, ACCOUNTS_INDEX_CONFIG_FOR_BENCHMARKS,
         },
     },
-    solana_sdk::pubkey::{self, Pubkey},
+    solana_sdk::{account::AccountSharedData, pubkey},
     test::Bencher,
 };
 
@@ -26,10 +26,10 @@ fn bench_accounts_index(bencher: &mut Bencher) {
     for f in 0..NUM_FORKS {
         for pubkey in pubkeys.iter().take(NUM_PUBKEYS) {
             index.upsert(
+                f,
                 f,
                 pubkey,
-                &Pubkey::default(),
-                &[],
+                &AccountSharedData::default(),
                 &AccountSecondaryIndexes::default(),
                 AccountInfo::default(),
                 &mut reclaims,
@@ -44,10 +44,10 @@ fn bench_accounts_index(bencher: &mut Bencher) {
         for _p in 0..NUM_PUBKEYS {
             let pubkey = thread_rng().gen_range(0, NUM_PUBKEYS);
             index.upsert(
+                fork,
                 fork,
                 &pubkeys[pubkey],
-                &Pubkey::default(),
-                &[],
+                &AccountSharedData::default(),
                 &AccountSecondaryIndexes::default(),
                 AccountInfo::default(),
                 &mut reclaims,
