@@ -1,16 +1,15 @@
 use {
     super::Bank,
+    solana_address_lookup_table_program::error::AddressLookupError,
     solana_sdk::{
         message::v0::{LoadedAddresses, MessageAddressTableLookup},
-        transaction::{
-            AddressLoader, AddressLookupError, Result as TransactionResult, TransactionError,
-        },
+        transaction::{AddressLoader, Result as TransactionResult, TransactionError},
     },
 };
 
-impl AddressLoader for Bank {
+impl AddressLoader for &Bank {
     fn load_addresses(
-        &self,
+        self,
         address_table_lookups: &[MessageAddressTableLookup],
     ) -> TransactionResult<LoadedAddresses> {
         if !self.versioned_tx_message_enabled() {
