@@ -64,6 +64,7 @@ impl MessageProcessor {
         blockhash: Hash,
         lamports_per_signature: u64,
         current_accounts_data_len: u64,
+        accumulated_consumed_units: &mut u64,
     ) -> Result<ProcessedMessageInfo, TransactionError> {
         let mut invoke_context = InvokeContext::new(
             transaction_context,
@@ -134,6 +135,8 @@ impl MessageProcessor {
                 timings,
             );
             time.stop();
+            *accumulated_consumed_units =
+                accumulated_consumed_units.saturating_add(compute_units_consumed);
             timings.details.accumulate_program(
                 program_id,
                 time.as_us(),
@@ -282,6 +285,7 @@ mod tests {
             Hash::default(),
             0,
             0,
+            &mut 0,
         );
         assert!(result.is_ok());
         assert_eq!(
@@ -330,6 +334,7 @@ mod tests {
             Hash::default(),
             0,
             0,
+            &mut 0,
         );
         assert_eq!(
             result,
@@ -368,6 +373,7 @@ mod tests {
             Hash::default(),
             0,
             0,
+            &mut 0,
         );
         assert_eq!(
             result,
@@ -503,6 +509,7 @@ mod tests {
             Hash::default(),
             0,
             0,
+            &mut 0,
         );
         assert_eq!(
             result,
@@ -536,6 +543,7 @@ mod tests {
             Hash::default(),
             0,
             0,
+            &mut 0,
         );
         assert!(result.is_ok());
 
@@ -566,6 +574,7 @@ mod tests {
             Hash::default(),
             0,
             0,
+            &mut 0,
         );
         assert!(result.is_ok());
         assert_eq!(
@@ -645,7 +654,9 @@ mod tests {
             Hash::default(),
             0,
             0,
+            &mut 0,
         );
+
         assert_eq!(
             result,
             Err(TransactionError::InstructionError(
